@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -500,12 +500,12 @@ public class GoogleEventConverter {
             }
         });
 
-        result.put(EventField.TIMESTAMP, new GoogleMapping() {
+        result.put(EventField.DTSTAMP, new GoogleMapping() {
 
             @Override
             public void serialize(Event to, com.google.api.services.calendar.model.Event from) {
                 if (from.getCreated() != null) {
-                    to.setTimestamp(from.getCreated().getValue());
+                    to.setDtStamp(from.getCreated().getValue());
                 }
             }
         });
