@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -28,7 +28,7 @@ import org.apache.http.client.utils.URIBuilder;
 import org.json.JSONObject;
 import com.openexchange.chronos.provider.ical.auth.AdvancedAuthInfo;
 import com.openexchange.chronos.provider.ical.auth.ICalAuthParser;
-import com.openexchange.chronos.provider.ical.properties.ICalCalendarProviderProperties;
+import com.openexchange.chronos.provider.ical.httpclient.properties.ICalCalendarProviderProperties;
 import com.openexchange.exception.OXException;
 import com.openexchange.session.Session;
 
