@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -29,6 +29,8 @@ import com.openexchange.auth.info.AuthType;
 import com.openexchange.chronos.exception.CalendarExceptionCodes;
 import com.openexchange.chronos.provider.CalendarAccountAttribute;
 import com.openexchange.chronos.provider.ical.auth.AdvancedAuthInfo.Builder;
+import com.openexchange.chronos.provider.ical.osgi.Services;
+import com.openexchange.crypto.CryptoService;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Strings;
 import com.openexchange.session.Session;
@@ -175,10 +177,10 @@ public class ICalAuthParser {
     }
 
     private static String encrypt(String passwordToEncrypt, String passwordToEncryptWith) throws OXException {
-        return PasswordUtil.encrypt(passwordToEncrypt, passwordToEncryptWith);
+        return Services.getService(CryptoService.class).encrypt(passwordToEncrypt, passwordToEncryptWith);
     }
 
     private static String decrypt(String passwordToEncrypt, String passwordToEncryptWith) throws OXException {
-        return PasswordUtil.decrypt(passwordToEncrypt, passwordToEncryptWith);
+        return Services.getService(CryptoService.class).decrypt(passwordToEncrypt, passwordToEncryptWith);
     }
 }
