@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -24,7 +24,6 @@ package com.openexchange.chronos.provider.ical.auth;
 import java.security.InvalidKeyException;
 import java.security.Key;
 import java.security.NoSuchAlgorithmException;
-import java.security.SecureRandom;
 import javax.crypto.BadPaddingException;
 import javax.crypto.Cipher;
 import javax.crypto.IllegalBlockSizeException;
@@ -33,8 +32,10 @@ import javax.crypto.NoSuchPaddingException;
 import javax.crypto.SecretKey;
 import javax.crypto.spec.SecretKeySpec;
 import com.openexchange.chronos.exception.CalendarExceptionCodes;
+import com.openexchange.crypto.CryptoService;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Charsets;
+import com.openexchange.java.CryptoUtil;
 
 /**
  * {@link PasswordUtil} - Utility class to encrypt/decrypt passwords with a key aka <b>p</b>assword <b>b</b>ased <b>e</b>ncryption
@@ -44,7 +45,9 @@ import com.openexchange.java.Charsets;
  *
  * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
  * @since v7.10.0
+ * @deprecated Use {@link CryptoService} instead.
  */
+@Deprecated
 public final class PasswordUtil {
 
     /** The logger constant */
@@ -179,7 +182,7 @@ public final class PasswordUtil {
      */
     public static Key generateRandomKey() throws NoSuchAlgorithmException {
         final KeyGenerator keyGenerator = KeyGenerator.getInstance(ALGORITHM_DES);
-        keyGenerator.init(new SecureRandom());
+        keyGenerator.init(CryptoUtil.getSecureRandom());
         final SecretKey secretKey = keyGenerator.generateKey();
         return secretKey;
     }
