@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -23,7 +23,6 @@ package com.openexchange.chronos.provider.ical.conn;
 
 import static com.openexchange.java.Autoboxing.L;
 import java.io.IOException;
-import java.io.InputStream;
 import java.net.URI;
 import java.net.UnknownHostException;
 import java.nio.charset.Charset;
@@ -50,8 +49,8 @@ import com.openexchange.chronos.ical.ImportedCalendar;
 import com.openexchange.chronos.provider.ical.ICalCalendarFeedConfig;
 import com.openexchange.chronos.provider.ical.auth.AdvancedAuthInfo;
 import com.openexchange.chronos.provider.ical.exception.ICalProviderExceptionCodes;
+import com.openexchange.chronos.provider.ical.httpclient.properties.ICalCalendarProviderProperties;
 import com.openexchange.chronos.provider.ical.osgi.Services;
-import com.openexchange.chronos.provider.ical.properties.ICalCalendarProviderProperties;
 import com.openexchange.chronos.provider.ical.result.GetResponse;
 import com.openexchange.chronos.provider.ical.result.GetResponseState;
 import com.openexchange.chronos.provider.ical.utils.ICalProviderUtils;
@@ -62,6 +61,7 @@ import com.openexchange.rest.client.httpclient.HttpClientService;
 import com.openexchange.rest.client.httpclient.HttpClients;
 import com.openexchange.rest.client.httpclient.ManagedHttpClient;
 import com.openexchange.session.Session;
+import com.openexchange.tools.stream.CountingInputStream;
 
 /**
  *
@@ -132,21 +132,41 @@ public class ICalFeedClient {
         }
     }
 
-    private ImportedCalendar importCalendar(HttpEntity httpEntity) throws OXException {
+    private ImportedCalendar importCalendar(HttpEntity httpEntity, long maxFeedSize) throws OXException {
         if (null == httpEntity) {
             return null;
         }
         ICalService iCalService = Services.getService(ICalService.class);
         ICalParameters parameters = iCalService.initParameters();
         parameters.set(ICalParameters.IGNORE_UNSET_PROPERTIES, Boolean.TRUE);
-        try (InputStream inputStream = Streams.bufferedInputStreamFor(httpEntity.getContent())) {
+        try (CountingInputStream inputStream = new CountingInputStream(Streams.bufferedInputStreamFor(httpEntity.getContent()), maxFeedSize, (total, max) -> wrapExceededError(max))) {
             return iCalService.importICal(inputStream, parameters);
         } catch (UnsupportedOperationException | IOException e) {
+            // @formatter:off
+            if(e instanceof IOException &&
+               e.getCause() instanceof OXException &&
+               ICalProviderExceptionCodes.FEED_SIZE_EXCEEDED.equals((OXException) e.getCause())) {
+                // Max download limit reached
+                throw (OXException) e.getCause();
+            }
+            // @formatter:on
             LOG.error("Error while processing the retrieved information:{}.", e.getMessage(), e);
             throw ICalProviderExceptionCodes.UNEXPECTED_FEED_ERROR.create(iCalFeedConfig.getFeedUrl(), e.getMessage());
         }
     }
 
+    /**
+     * Wraps a new {@link ICalProviderExceptionCodes#FEED_SIZE_EXCEEDED} error inside an {@link IOException}
+     *
+     * @param max The maximal amount of bytes allowed
+     * @return The {@link IOException}
+     */
+    private IOException wrapExceededError(long max) {
+        String msg = new StringBuilder(32).append("Max. byte count of ").append(max).append(" exceeded.").toString();
+        OXException oxe = ICalProviderExceptionCodes.FEED_SIZE_EXCEEDED.create(iCalFeedConfig.getFeedUrl(), L(max), L(-1));
+        return new IOException(msg, oxe);
+    }
+
     /**
      * Returns the calendar behind the given feed URL if available. If there is no update (based on etag and last modification header) the contained calendar will be <code>null</code>.
      *
@@ -203,7 +223,7 @@ public class ICalFeedClient {
         if (contentLength > allowedFeedSize || (Strings.isNotEmpty(contentLength2) && Long.parseLong(contentLength2) > allowedFeedSize)) {
             throw ICalProviderExceptionCodes.FEED_SIZE_EXCEEDED.create(iCalFeedConfig.getFeedUrl(), L(allowedFeedSize), contentLength2 != null ? contentLength2 : L(contentLength));
         }
-        response.setCalendar(importCalendar(entity));
+        response.setCalendar(importCalendar(entity, allowedFeedSize));
         return response;
     }
 
