@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -26,8 +26,8 @@ import com.openexchange.chronos.ical.ICalService;
 import com.openexchange.chronos.provider.CalendarProvider;
 import com.openexchange.chronos.provider.account.AdministrativeCalendarAccountService;
 import com.openexchange.chronos.provider.ical.BasicICalCalendarProvider;
-import com.openexchange.chronos.provider.ical.properties.ICalCalendarProviderReloadable;
-import com.openexchange.chronos.provider.ical.properties.IcalCalendarHttpProperties;
+import com.openexchange.chronos.provider.ical.httpclient.properties.ICalCalendarProviderReloadable;
+import com.openexchange.chronos.provider.ical.httpclient.properties.IcalCalendarHttpProperties;
 import com.openexchange.chronos.service.CalendarUtilities;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Reloadable;
