@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -26,8 +26,9 @@ import java.net.URI;
 import java.net.URISyntaxException;
 import java.net.UnknownHostException;
 import com.openexchange.chronos.provider.ical.exception.ICalProviderExceptionCodes;
-import com.openexchange.chronos.provider.ical.properties.ICalCalendarProviderProperties;
+import com.openexchange.chronos.provider.ical.httpclient.properties.ICalCalendarProviderProperties;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.InetAddresses;
 import com.openexchange.java.Strings;
 
 /**
@@ -63,7 +64,7 @@ public class ICalProviderUtils {
 
     private static boolean isValid(URI uri) {
         try {
-            InetAddress inetAddress = InetAddress.getByName(uri.getHost());
+            InetAddress inetAddress = InetAddresses.forString(uri.getHost());
             if (inetAddress.isAnyLocalAddress() || inetAddress.isSiteLocalAddress() || inetAddress.isLoopbackAddress() || inetAddress.isLinkLocalAddress()) {
                 org.slf4j.LoggerFactory.getLogger(ICalProviderUtils.class).debug("Given feed URL \"{}\" with destination IP {} appears not to be valid.", uri.toString(), inetAddress.getHostAddress());
                 return false;
