@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -55,20 +55,21 @@ import com.openexchange.chronos.provider.CalendarPermission;
 import com.openexchange.chronos.provider.DefaultCalendarPermission;
 import com.openexchange.chronos.service.CalendarResult;
 import com.openexchange.chronos.service.CalendarSession;
-import com.openexchange.chronos.service.CollectionUpdate;
 import com.openexchange.chronos.service.CreateResult;
 import com.openexchange.chronos.service.DeleteResult;
 import com.openexchange.chronos.service.EventID;
 import com.openexchange.chronos.service.EventsResult;
 import com.openexchange.chronos.service.ImportResult;
-import com.openexchange.chronos.service.ItemUpdate;
-import com.openexchange.chronos.service.SimpleCollectionUpdate;
+import com.openexchange.chronos.service.RecurrenceInfo;
 import com.openexchange.chronos.service.UpdateResult;
 import com.openexchange.chronos.service.UpdatesResult;
 import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.exception.OXException;
 import com.openexchange.group.GroupService;
 import com.openexchange.groupware.EntityInfo;
+import com.openexchange.groupware.tools.mappings.common.CollectionUpdate;
+import com.openexchange.groupware.tools.mappings.common.ItemUpdate;
+import com.openexchange.groupware.tools.mappings.common.SimpleCollectionUpdate;
 import com.openexchange.java.Strings;
 import com.openexchange.java.util.Pair;
 import com.openexchange.server.ServiceLookup;
@@ -648,7 +649,7 @@ public class EntityHelper extends XctxEntityHelper {
         for (Event event : events) {
             mangledEvents.add(mangleRemoteEvent(event));
         }
-        return events;
+        return mangledEvents;
     }
 
     public Event mangleRemoteEvent(Event event) {
@@ -681,6 +682,31 @@ public class EntityHelper extends XctxEntityHelper {
         };
     }
 
+    public RecurrenceInfo mangleRemoteRecurrenceInfo(RecurrenceInfo recurrenceInfo) {
+        return new RecurrenceInfo() {
+
+            @Override
+            public boolean isRescheduled() {
+                return recurrenceInfo.isRescheduled();
+            }
+
+            @Override
+            public boolean isOverridden() {
+                return recurrenceInfo.isOverridden();
+            }
+
+            @Override
+            public Event getSeriesMaster() {
+                return mangleRemoteEvent(recurrenceInfo.getSeriesMaster());
+            }
+
+            @Override
+            public Event getRecurrence() {
+                return mangleRemoteEvent(recurrenceInfo.getRecurrence());
+            }
+        };
+    }
+
     List<Attendee> mangleRemoteAttendees(List<Attendee> attendees) {
         if (null == attendees || attendees.isEmpty()) {
             return attendees;
