@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -30,17 +30,14 @@ import static com.openexchange.chronos.provider.xctx.Constants.SHARED_FOLDER_ID;
 import static com.openexchange.chronos.provider.xctx.Constants.TREE_ID;
 import static com.openexchange.chronos.service.CalendarParameters.PARAMETER_IGNORE_STORAGE_WARNINGS;
 import static com.openexchange.folderstorage.CalendarFolderConverter.getStorageFolder;
-import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.java.Autoboxing.b;
 import static com.openexchange.osgi.Tools.requireService;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.Date;
 import java.util.EnumSet;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.Map.Entry;
 import org.dmfs.rfc5545.DateTime;
 import org.json.JSONObject;
 import org.slf4j.Logger;
@@ -48,13 +45,14 @@ import org.slf4j.LoggerFactory;
 import com.openexchange.ajax.fileholder.IFileHolder;
 import com.openexchange.chronos.Alarm;
 import com.openexchange.chronos.Attendee;
+import com.openexchange.chronos.CalendarObjectResource;
 import com.openexchange.chronos.CalendarUserType;
 import com.openexchange.chronos.Event;
 import com.openexchange.chronos.ExtendedProperties;
 import com.openexchange.chronos.Organizer;
 import com.openexchange.chronos.RecurrenceId;
-import com.openexchange.chronos.common.CalendarUtils;
 import com.openexchange.chronos.common.Check;
+import com.openexchange.chronos.common.DefaultCalendarObjectResource;
 import com.openexchange.chronos.common.DefaultCalendarParameters;
 import com.openexchange.chronos.exception.CalendarExceptionCodes;
 import com.openexchange.chronos.provider.CalendarAccount;
@@ -79,8 +77,8 @@ import com.openexchange.chronos.service.CalendarService;
 import com.openexchange.chronos.service.CalendarSession;
 import com.openexchange.chronos.service.EventID;
 import com.openexchange.chronos.service.EventsResult;
-import com.openexchange.chronos.service.FreeBusyResult;
 import com.openexchange.chronos.service.ImportResult;
+import com.openexchange.chronos.service.RecurrenceInfo;
 import com.openexchange.chronos.service.SearchFilter;
 import com.openexchange.chronos.service.UpdatesResult;
 import com.openexchange.exception.OXException;
@@ -94,6 +92,7 @@ import com.openexchange.folderstorage.Permissions;
 import com.openexchange.folderstorage.UserizedFolder;
 import com.openexchange.java.util.TimeZones;
 import com.openexchange.quota.Quota;
+import com.openexchange.search.SearchTerm;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.session.Session;
 import com.openexchange.share.subscription.ShareSubscriptionExceptions;
@@ -283,6 +282,12 @@ public class XctxCalendarAccess implements SubscribeAware, GroupwareCalendarAcce
         Map<String, EventsResult> resultsPerFolder = getCalendarService().searchEvents(guestSession, folderIds, filters, queries);
         return entityHelper.mangleMappedEventsResults(resultsPerFolder);
     }
+    
+    @Override
+    public Map<String, EventsResult> searchEvents(List<String> folderIds, SearchTerm<?> term) throws OXException {
+        Map<String, EventsResult> resultsPerFolder = getCalendarService().searchEvents(guestSession, folderIds, term);
+        return entityHelper.mangleMappedEventsResults(resultsPerFolder);
+    }
 
     @Override
     public CalendarResult createEvent(String folderId, Event event) throws OXException {
@@ -292,6 +297,17 @@ public class XctxCalendarAccess implements SubscribeAware, GroupwareCalendarAcce
         return entityHelper.mangleRemoteCalendarResult(calendarResult);
     }
 
+    @Override
+    public CalendarResult putResource(String folderId, CalendarObjectResource resource, boolean replace) throws OXException {
+        List<Event> unmangledEventData = new ArrayList<Event>();
+        for (Event event : resource.getEvents()) {
+            Check.containsNoSuchAttendees(event, Boolean.TRUE, CalendarUserType.RESOURCE, CalendarUserType.ROOM, CalendarUserType.GROUP);
+            unmangledEventData.add(entityHelper.unmangleLocalEvent(event));
+        }
+        CalendarResult calendarResult = getCalendarService().putResource(guestSession, folderId, new DefaultCalendarObjectResource(unmangledEventData), replace);
+        return entityHelper.mangleRemoteCalendarResult(calendarResult);
+    }
+
     @Override
     public CalendarResult updateEvent(EventID eventID, Event event, long clientTimestamp) throws OXException {
         Check.containsNoSuchAttendees(event, Boolean.TRUE, CalendarUserType.RESOURCE, CalendarUserType.ROOM, CalendarUserType.GROUP);
@@ -320,6 +336,12 @@ public class XctxCalendarAccess implements SubscribeAware, GroupwareCalendarAcce
         return entityHelper.mangleRemoteCalendarResult(calendarResult);
     }
 
+    @Override
+    public RecurrenceInfo getRecurrenceInfo(EventID eventID) throws OXException {
+        RecurrenceInfo recurrenceInfo = getCalendarService().getUtilities().getRecurrenceInfo(guestSession, eventID);
+        return entityHelper.mangleRemoteRecurrenceInfo(recurrenceInfo);
+    }
+
     @Override
     public CalendarResult deleteEvent(EventID eventID, long clientTimestamp) throws OXException {
         CalendarResult calendarResult = getCalendarService().deleteEvent(guestSession, eventID, clientTimestamp);
@@ -364,39 +386,6 @@ public class XctxCalendarAccess implements SubscribeAware, GroupwareCalendarAcce
         return warnings;
     }
 
-    /**
-     * Gets free/busy information in a certain interval for one ore more attendees.
-     * <p/>
-     * Optionally, the resulting data is pre-processed and sorted by time, so that any overlapping intervals each of the attendee's
-     * free/busy time are merged implicitly to the most conflicting busy times.
-     *
-     * @param attendees The attendees to get the free/busy data for
-     * @param from The start of the requested time range
-     * @param until The end of the requested time range
-     * @param merge <code>true</code> to merge the resulting free/busy-times, <code>false</code>, otherwise
-     * @return The free/busy times for each of the requested attendees, wrapped within a free/busy result structure
-     */
-    public Map<Attendee, FreeBusyResult> getFreeBusy(List<Attendee> attendees, Date from, Date until, boolean merge) throws OXException {
-        List<Attendee> unmangledAttendees = entityHelper.unmangleLocalAttendees(attendees);
-        Map<Attendee, FreeBusyResult> result = guestSession.getFreeBusyService().getFreeBusy(guestSession, unmangledAttendees, from, until, merge);
-        if (null == result || result.isEmpty()) {
-            return result;
-        }
-        Map<Attendee, FreeBusyResult> mangledResult = new HashMap<Attendee, FreeBusyResult>(result.size());
-        for (Entry<Attendee, FreeBusyResult> entry : result.entrySet()) {
-            /*
-             * attendee may have been resolved to internal user in remote context; check
-             */
-            Attendee attendee = CalendarUtils.find(attendees, entityHelper.mangleRemoteAttendee(entry.getKey()));
-            if (null == attendee) {
-                LOG.debug("Skipping unexpected attendee {} in free/busy results from account {}", attendee, I(account.getAccountId()));
-                continue;
-            }
-            mangledResult.put(attendee, entry.getValue());
-        }
-        return mangledResult;
-    }
-
     private List<CalendarFolder> getVisibleFolders(boolean all) throws OXException {
         List<CalendarFolder> folders = getVisibleFolders();
         if (null == folders || folders.isEmpty() || all) {
