@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -52,7 +52,7 @@ import com.openexchange.chronos.service.CalendarParameters;
 import com.openexchange.exception.OXException;
 import com.openexchange.folderstorage.FolderExceptionErrorMessage;
 import com.openexchange.groupware.modules.Module;
-import com.openexchange.groupware.tools.alias.UserAliasUtility;
+import com.openexchange.mail.alias.UserAliasUtility;
 import com.openexchange.java.Strings;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.session.Session;
@@ -283,7 +283,7 @@ public class XctxShareSubscriptionProvider implements ShareSubscriptionProvider
     }
 
     protected static Set<String> getAliases(User user) {
-        Set<String> possibleAliases = new HashSet<String>();
+        Set<String> possibleAliases = new HashSet<>();
         if (Strings.isNotEmpty(user.getMail())) {
             possibleAliases.add(user.getMail());
         }
