@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -103,10 +103,8 @@ public class SchedJoulesServiceImpl implements SchedJoulesService, Reloadable {
 
     /**
      * Initialises a new {@link SchedJoulesServiceImpl}.
-     *
-     * @throws OXException if the {@link SchedJoulesAPI} cannot be initialised
      */
-    public SchedJoulesServiceImpl() throws OXException {
+    public SchedJoulesServiceImpl() {
         super();
         initialiseBlackListedItems();
     }
