@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -108,17 +108,4 @@ public class SchedJoulesAPICache {
         }
         return value;
     }
-
-    /**
-     * Retrieves the desired {@link SchedJoulesProperty} for the specified context
-     *
-     * @param contextId The context identifier
-     * @param property The {@link SchedJoulesProperty} to get
-     * @return The integer property
-     * @throws OXException if no property is configured
-     */
-    private int getIntProperty(int contextId, SchedJoulesProperty property) throws OXException {
-        LeanConfigurationService leanConfigService = Services.getService(LeanConfigurationService.class);
-        return leanConfigService.getIntProperty(-1, contextId, property);
-    }
 }
