@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -40,10 +40,6 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import com.openexchange.annotation.Nullable;
 import com.openexchange.api.client.ApiClient;
-import com.openexchange.api.client.common.calls.find.FindResponse;
-import com.openexchange.api.client.common.calls.find.QueryCall;
-import com.openexchange.api.client.common.calls.find.QueryCall.FacetFilter;
-import com.openexchange.api.client.common.calls.find.QueryCall.QueryBuilder;
 import com.openexchange.api.client.common.calls.folders.DeleteFolderCall;
 import com.openexchange.api.client.common.calls.folders.FolderBody;
 import com.openexchange.api.client.common.calls.folders.GetFolderCall;
@@ -71,7 +67,6 @@ import com.openexchange.api.client.common.calls.infostore.UnlockCall;
 import com.openexchange.api.client.common.calls.infostore.UpdatesCall;
 import com.openexchange.api.client.common.calls.infostore.UpdatesResponse;
 import com.openexchange.api.client.common.calls.infostore.VersionsCall;
-import com.openexchange.api.client.common.calls.infostore.mapping.DefaultFileMapper;
 import com.openexchange.api.client.common.calls.system.ServerVersionCall;
 import com.openexchange.api.client.common.calls.system.WhoamiCall;
 import com.openexchange.exception.OXException;
@@ -84,6 +79,7 @@ import com.openexchange.file.storage.FileStorageFileAccess.IDTuple;
 import com.openexchange.file.storage.FileStorageFileAccess.SortDirection;
 import com.openexchange.file.storage.FileStorageFolder;
 import com.openexchange.file.storage.Range;
+import com.openexchange.file.storage.search.FileNameTerm;
 import com.openexchange.file.storage.search.SearchTerm;
 import com.openexchange.file.storage.search.ToJsonSearchTermVisitor;
 import com.openexchange.folderstorage.FolderStorage;
@@ -637,29 +633,18 @@ public class ShareClient {
      * @throws OXException If operation fails
      */
     public List<File> search(String pattern, List<Field> fields, String folderId, boolean includeSubfolders, Field sort, SortDirection order, int start, int end) throws OXException {
-        //Build the query
+        final boolean substringSearch = pattern != null && pattern.contains("*");
+        final boolean ignoreCase = true;
         //@formatter:off
-        final QueryBuilder builder = new QueryBuilder()
-            .withStart(start)
-            .withSize(end - start)
-            .withTimezone(TIMEZONE_UTC)
-            .withFacet(SEARCH_FACET_ACCOUNT, INFOSTORE_ACCOUNT_ID)
-            .withFacet(SEARCH_FACET_FOLDER, folderId)
-            .withFacet("file_name", "file_name:" + pattern,new FacetFilter().setFields(Field.FILENAME.getName()).setQueries(pattern))
-            .includeSubfolders(includeSubfolders);
+        return advancedSearch(folderId,
+                              includeSubfolders,
+                              new FileNameTerm(pattern, ignoreCase, substringSearch),
+                              fields,
+                              sort,
+                              order,
+                              start,
+                              end);
         //@formatter:on
-
-        //Add sorting
-        QueryCall.SortOrder sortOrder = null;
-        if (sort != null && order != null) {
-            sortOrder = order == SortDirection.DESC ? QueryCall.SortOrder.DESC : QueryCall.SortOrder.ASC;
-            builder.sortBy(sort.getNumber()).withSortOrder(sortOrder);
-        }
-
-        //Search
-        int[] columns = toIdList(getFieldsToQuery(fields, Field.SEQUENCE_NUMBER));
-        FindResponse<DefaultFile> result = getApiClient().execute(new QueryCall<DefaultFile, File.Field>(MODULE_FILES, columns, builder.build(), new DefaultFileMapper()));
-        return fileConverter.getStorageFiles(result.getResultObjects(), fields);
     }
 
     /**
