@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -68,6 +68,7 @@ import com.openexchange.server.ServiceLookup;
 import com.openexchange.server.impl.OCLPermission;
 import com.openexchange.subscribe.Subscription;
 import com.openexchange.subscribe.SubscriptionErrorMessage;
+import com.openexchange.subscribe.dav.httpclient.properties.DAVSubscribeHttpProperties;
 import com.openexchange.subscribe.dav.osgi.Services;
 import com.openexchange.threadpool.AbstractTask;
 import com.openexchange.threadpool.Task;
@@ -104,6 +105,14 @@ public abstract class AbstractCardDAVSubscribeService extends AbstractDAVSubscri
         return DAVFolderModule.CONTACTS;
     }
 
+    private static HttpClient getHttpClient() throws OXException {
+        HttpClientService httpClientService = Services.getOptionalService(HttpClientService.class);
+        if (httpClientService == null) {
+            throw ServiceExceptionCode.absentService(HttpClientService.class);
+        }
+        return httpClientService.getHttpClient(DAVSubscribeHttpProperties.getHttpClientId());
+    }
+
     @Override
     public Collection<?> getContent(final Subscription subscription) throws OXException {
         final VCardService vcardService = Services.getOptionalService(VCardService.class);
@@ -230,11 +239,7 @@ public abstract class AbstractCardDAVSubscribeService extends AbstractDAVSubscri
             propfind.setHeader(HttpHeaders.DEPTH, "1");
 
             {
-                StringBuilder xmlBody = new StringBuilder(
-                    "<c:addressbook-multiget xmlns:d=\"DAV:\" xmlns:c=\"urn:ietf:params:xml:ns:carddav\">\n" +
-                    "  <d:prop>\n" +
-                    "     <c:address-data />\n" +
-                    "  </d:prop>\n");
+                StringBuilder xmlBody = new StringBuilder("<c:addressbook-multiget xmlns:d=\"DAV:\" xmlns:c=\"urn:ietf:params:xml:ns:carddav\">\n" + "  <d:prop>\n" + "     <c:address-data />\n" + "  </d:prop>\n");
 
                 for (String contactHref : contactHrefs) {
                     xmlBody.append("  <d:href>").append(contactHref).append("</d:href>\n");
@@ -313,12 +318,7 @@ public abstract class AbstractCardDAVSubscribeService extends AbstractDAVSubscri
             propfind.setHeader(HttpHeaders.DEPTH, "1");
 
             {
-                String xmlBody =
-                    "<d:propfind xmlns:d=\"DAV:\" xmlns:c=\"urn:ietf:params:xml:ns:carddav\" xmlns:cs=\"http://calendarserver.org/ns/\">\n" +
-                    "  <d:prop>\n" +
-                    "     <c:addressbook-home-set/>\n" +
-                    "  </d:prop>\n" +
-                    "</d:propfind>";
+                String xmlBody = "<d:propfind xmlns:d=\"DAV:\" xmlns:c=\"urn:ietf:params:xml:ns:carddav\" xmlns:cs=\"http://calendarserver.org/ns/\">\n" + "  <d:prop>\n" + "     <c:addressbook-home-set/>\n" + "  </d:prop>\n" + "</d:propfind>";
                 propfind.setEntity(new StringEntity(xmlBody, ContentType.TEXT_XML));
             }
 
@@ -390,13 +390,7 @@ public abstract class AbstractCardDAVSubscribeService extends AbstractDAVSubscri
             propfind.setHeader(HttpHeaders.DEPTH, "1");
 
             {
-                String xmlBody =
-                    "<d:propfind xmlns:d=\"DAV:\" xmlns:c=\"urn:ietf:params:xml:ns:carddav\" xmlns:cs=\"http://calendarserver.org/ns/\">\n" +
-                    "  <d:prop>\n" +
-                    "     <d:getetag />\n" +
-                    "     <d:getcontenttype />\n" +
-                    "  </d:prop>\n" +
-                    "</d:propfind>";
+                String xmlBody = "<d:propfind xmlns:d=\"DAV:\" xmlns:c=\"urn:ietf:params:xml:ns:carddav\" xmlns:cs=\"http://calendarserver.org/ns/\">\n" + "  <d:prop>\n" + "     <d:getetag />\n" + "     <d:getcontenttype />\n" + "  </d:prop>\n" + "</d:propfind>";
                 propfind.setEntity(new StringEntity(xmlBody, ContentType.TEXT_XML));
             }
 
@@ -488,15 +482,7 @@ public abstract class AbstractCardDAVSubscribeService extends AbstractDAVSubscri
             propfind.setHeader(HttpHeaders.DEPTH, "1");
 
             {
-                String xmlBody =
-                    "<d:propfind xmlns:d=\"DAV:\" xmlns:cs=\"http://calendarserver.org/ns/\">\n" +
-                    "  <d:prop>\n" +
-                    "     <d:displayname />\n" +
-                    "     <d:resourcetype />\n" +
-                    "     <cs:getctag />\n" +
-                    "     <d:current-user-principal />\n" +
-                    "  </d:prop>\n" +
-                    "</d:propfind>";
+                String xmlBody = "<d:propfind xmlns:d=\"DAV:\" xmlns:cs=\"http://calendarserver.org/ns/\">\n" + "  <d:prop>\n" + "     <d:displayname />\n" + "     <d:resourcetype />\n" + "     <cs:getctag />\n" + "     <d:current-user-principal />\n" + "  </d:prop>\n" + "</d:propfind>";
                 propfind.setEntity(new StringEntity(xmlBody, ContentType.TEXT_XML));
             }
 
@@ -592,10 +578,6 @@ public abstract class AbstractCardDAVSubscribeService extends AbstractDAVSubscri
         return ((Element) value).getTextContent();
     }
 
-    private HttpClient getHttpClient() throws OXException {
-        return services.getServiceSafe(HttpClientService.class).getHttpClient(CLIENT_ID);
-    }
-
     /**
      * Gets the base URL; e.g. <code>"https://carddav.providerx.org/CardDavProxy/carddav"</code>
      *
