@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -76,7 +76,7 @@ public class OAuthServiceMetaDataRegisterer implements ServiceTrackerCustomizer<
             try {
                 subscribeService = new GoogleContactsSubscribeService(oAuthServiceMetaData, services);
             } catch (OXException e) {
-                logger.error("Unable to create Google Contact subscription services: " + e.getMessage(), e);
+                logger.error("Unable to create Google Contact subscription services", e);
                 return null;
             }
             contactsRegistration = context.registerService(SubscribeService.class, subscribeService, null);
