@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -22,10 +22,15 @@
 package com.openexchange.subscribe.json;
 
 import java.util.Map;
+import java.util.Optional;
 import org.json.JSONException;
 import org.json.JSONObject;
+import com.openexchange.contact.common.ContactsAccount;
 import com.openexchange.datatypes.genericonf.json.FormContentParser;
+import com.openexchange.exception.OXException;
+import com.openexchange.java.Strings;
 import com.openexchange.subscribe.Subscription;
+import com.openexchange.subscribe.SubscriptionErrorMessage;
 import com.openexchange.subscribe.SubscriptionSource;
 import com.openexchange.subscribe.SubscriptionSourceDiscoveryService;
 
@@ -48,13 +53,14 @@ public class SubscriptionJSONParser {
         this.discovery = discovery;
     }
 
-    public Subscription parse(JSONObject object) throws JSONException {
+    public Subscription parse(JSONObject object) throws JSONException, OXException {
         Subscription subscription = new Subscription();
         if (object.has("id")) {
             subscription.setId(object.getInt("id"));
         }
         if (object.has("folder")) {
-            subscription.setFolderId(object.getString("folder"));
+            String folderId = object.getString("folder");
+            subscription.setFolderId(adjustFolderId(folderId));
         }
         if (object.has("enabled")) {
             subscription.setEnabled(object.getBoolean("enabled"));
@@ -73,4 +79,31 @@ public class SubscriptionJSONParser {
         return subscription;
     }
 
+    /**
+     * Adjusts a client-supplied folder identifier where the targeted groupware object is located at to be used within the internal
+     * subscription service.
+     * <p/>
+     * This can be used to still allow composite folder identifiers (for contacts folders) in the API.
+     * 
+     * @param requestedFolderId The folder identifier as requested by the client
+     * @return The optionally adjusted folder identifier (in <i>unmangled</i> form ) for further usage, or an empty {@link Optional} instance if not applicable
+     * @throws OXException In case folder ID can't be parsed
+     */
+    public static String adjustFolderId(String requestedFolderId) throws OXException {
+        if (-1 != Strings.parsePositiveInt(requestedFolderId)) {
+            return requestedFolderId; // use numerical identifier as-is
+        }
+        /*
+         * adjust to relative id if folder originates from default contacts account
+         */
+        try {
+            if (ContactsAccount.DEFAULT_ACCOUNT.getAccountId() == com.openexchange.contact.provider.composition.IDMangling.getAccountId(requestedFolderId)) {
+                return com.openexchange.contact.provider.composition.IDMangling.getRelativeFolderId(requestedFolderId);
+            }
+        } catch (Exception e) {
+            org.slf4j.LoggerFactory.getLogger(SubscriptionJSONParser.class).debug("Couldn't extract contact account id from {}", requestedFolderId, e);
+        }
+        throw SubscriptionErrorMessage.ParseException.create("Unable to parse folder ID");
+    }
+
 }
