@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -43,6 +43,7 @@ import com.google.common.collect.ImmutableSet;
 import com.openexchange.ajax.fields.ResponseFields;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.java.Strings;
 import com.openexchange.multiple.MultipleHandler;
 import com.openexchange.secret.SecretService;
 import com.openexchange.subscribe.SubscribeService;
@@ -142,7 +143,7 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
         List<Subscription> subscriptionsToRefresh = new LinkedList<>();
         TIntSet ids = new TIntHashSet();
         if (request.has("folder")) {
-            final String folderId = request.getString("folder");
+            final String folderId = SubscriptionJSONParser.adjustFolderId(request.getString("folder"));
             List<Subscription> allSubscriptions = null;
             allSubscriptions = getSubscriptionsInFolder(session, folderId, secretService.getSecret(session));
             Collections.sort(allSubscriptions, new Comparator<Subscription>() {
@@ -206,7 +207,7 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
         String folderId = null;
         boolean containsFolder = false;
         if (request.has("folder")) {
-            folderId = request.getString("folder");
+            folderId = SubscriptionJSONParser.adjustFolderId(request.getString("folder"));
             containsFolder = true;
         }
 
@@ -274,7 +275,7 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
         for (final String identifier : identifiers) {
             final String columns = request.optString(identifier);
             if (columns != null && !columns.equals("")) {
-                dynamicColumns.put(identifier, columns.split("\\s*,\\s*"));
+                dynamicColumns.put(identifier, Strings.splitByComma(columns));
             }
         }
         return dynamicColumns;
@@ -284,7 +285,7 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
 
     private List<String> getDynamicColumnOrder(JSONObject request) throws JSONException {
         if (request.has("dynamicColumnPlugins")) {
-            return Arrays.asList(request.getString("dynamicColumnPlugins").split("\\s*,\\s*"));
+            return Arrays.asList(Strings.splitByComma(request.getString("dynamicColumnPlugins")));
         }
 
         List<String> dynamicColumnIdentifiers = new ArrayList<>();
@@ -303,7 +304,7 @@ public class SubscriptionMultipleHandler implements MultipleHandler {
         if (columns == null || columns.equals("")) {
             return new String[] { "id", "folder", "source", "displayName", "enabled" };
         }
-        return columns.split("\\s*,\\s*");
+        return Strings.splitByComma(columns);
     }
 
     private Object loadSubscription(final JSONObject request, final ServerSession session) throws JSONException, OXException {
