@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -39,6 +39,7 @@ import com.openexchange.i18n.I18nService;
 import com.openexchange.i18n.I18nServiceRegistry;
 import com.openexchange.i18n.I18nTranslator;
 import com.openexchange.i18n.Translator;
+import com.openexchange.java.Strings;
 import com.openexchange.multiple.MultipleHandler;
 import com.openexchange.subscribe.SubscriptionSource;
 import com.openexchange.subscribe.SubscriptionSourceDiscoveryService;
@@ -122,7 +123,7 @@ public class SubscriptionSourceMultipleHandler implements MultipleHandler {
         if (columns == null) {
             return new String[] { "id", "displayName", "module", "icon", "formDescription" };
         }
-        return columns.split("\\s*,\\s*");
+        return Strings.splitByComma(columns);
     }
 
     protected JSONValue getSource(final JSONObject req, final ServerSession session) throws OXException, JSONException {
