@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -36,6 +36,7 @@ import com.openexchange.subscribe.FallbackSubscriptionService;
 import com.openexchange.subscribe.SubscribeService;
 import com.openexchange.subscribe.Subscription;
 import com.openexchange.subscribe.SubscriptionSource;
+import com.openexchange.subscribe.json.SubscriptionJSONParser;
 import com.openexchange.tools.session.ServerSession;
 
 /**
@@ -60,7 +61,7 @@ public class AllSubscriptionAction extends AbstractSubscribeAction {
         boolean containsFolder = false;
 
         if (subscribeRequest.getRequestData().getParameter("folder") != null) {
-            folderId = subscribeRequest.getRequestData().getParameter("folder");
+            folderId = SubscriptionJSONParser.adjustFolderId(subscribeRequest.getRequestData().getParameter("folder"));
             containsFolder = true;
         }
 
