@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -34,6 +34,7 @@ import com.openexchange.server.ServiceLookup;
 import com.openexchange.subscribe.FallbackSubscriptionService;
 import com.openexchange.subscribe.Subscription;
 import com.openexchange.subscribe.SubscriptionExecutionService;
+import com.openexchange.subscribe.json.SubscriptionJSONParser;
 import gnu.trove.set.TIntSet;
 import gnu.trove.set.hash.TIntHashSet;
 
@@ -59,8 +60,7 @@ public class RefreshSubscriptionAction extends AbstractSubscribeAction {
         final TIntSet ids = new TIntHashSet();
         JSONObject parameters = new JSONObject(subscribeRequest.getRequestData().getParameters());
         if (parameters.has("folder")) {
-            String folderId;
-            folderId = parameters.getString("folder");
+            String folderId = SubscriptionJSONParser.adjustFolderId(parameters.getString("folder"));
             List<Subscription> allSubscriptions = null;
             allSubscriptions = getSubscriptionsInFolder(
                 subscribeRequest.getServerSession(),
